pub struct ProfileBannerOption {
pub width: Option<String>,
pub height: Option<String>,
pub offset_left: Option<String>,
pub offset_top: Option<String>,
}Expand description
Options for updating the profile banner
Fields
width: Option<String>The width of the preferred section of the image being uploaded in pixels. Use with height , offset_left , and offset_top to select the desired region of the image to use.
height: Option<String>The height of the preferred section of the image being uploaded in pixels. Use with width , offset_left , and offset_top to select the desired region of the image to use.
offset_left: Option<String>The number of pixels by which to offset the uploaded image from the left. Use with height , width , and offset_top to select the desired region of the image to use.
offset_top: Option<String>The number of pixels by which to offset the uploaded image from the top. Use with height , width , and offset_left to select the desired region of the image to use.