pub struct UserProfile {
pub name: Option<String>,
pub url: Option<String>,
pub location: Option<String>,
pub description: Option<String>,
pub profile_link_color: Option<String>,
}Expand description
Options for updating the user profile
Fields
name: Option<String>Full name associated with the profile.
url: Option<String>URL associated with the profile. Will be prepended with http:// if not present.
location: Option<String>The city or country describing where the user of the account is located. The contents are not normalized or geocoded in any way.
description: Option<String>A description of the user owning the account.
profile_link_color: Option<String>Sets a hex value that controls the color scheme of links used on the authenticating user’s profile page on twitter.com. This must be a valid hexadecimal value, and may be either three or six characters (ex: F00 or FF0000). This parameter replaces the deprecated (and separate) update_profile_colors API method.