pub struct ListCursor {
pub previous_cursor: i64,
pub next_cursor: i64,
pub lists: Vec<List>,
}Expand description
Represents a single-page view into a list of lists.
This type is intended to be used in the background by CursorIter to hold an intermediate
list of lists to iterate over. See that struct’s documentation for details.
Fields
previous_cursor: i64Numeric reference to the previous page of results.
next_cursor: i64Numeric reference to the next page of results.
lists: Vec<List>The list of lists in this page of results.