UserCursor

Struct UserCursor 

pub struct UserCursor {
    pub previous_cursor: i64,
    pub next_cursor: i64,
    pub users: Vec<TwitterUser>,
}
Represents a single-page view into a list of users.

This type is intended to be used in the background by CursorIter to hold an intermediate list of users to iterate over. See that struct’s documentation for details.

Fields

previous_cursor: i64

Numeric reference to the previous page of results.

next_cursor: i64

Numeric reference to the next page of results.

users: Vec<TwitterUser>

The list of users in this page of results.