[−][src]Function egg_mode::direct::delete
pub async fn delete<'_>(
id: u64,
token: &'_ Token
) -> Result<Response<DirectMessage>, Error>
👎 Deprecated since 0.15:
the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Delete the direct message with the given ID.
The authenticated user must be the sender of this DM for this call to be successful.
On a successful deletion, the future returned by this function yields the freshly-deleted message.