pub fn list(token: &Token) -> TimelineExpand description
Load the list of direct messages sent and received by the authorized user.
This function will only return the messages sent and received in the last 30 days. For more
information, see the docs for Timeline.