[][src]Type Definition egg_mode::direct::DMConversations

type DMConversations = HashMap<u64, Vec<DirectMessage>>;
👎 Deprecated since 0.15:

the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API

Wrapper around a collection of direct messages, sorted by their recipient.

The mapping exposed here is from a User ID to a listing of direct messages between the authenticated user and that user. For more information, see the docs for ConversationTimeline.