Enum egg_mode::entities::ResizeMode [−][src]
pub enum ResizeMode {
Fit,
Crop,
}Expand description
Represents how an image has been resized for a given size variant.
Variants
The media was resized to fit one dimension, keeping its aspect ratio.
The media was cropped to fit a specific resolution.