Struct egg_mode::entities::HashtagEntity [−][src]
Represents a hashtag or symbol extracted from another piece of text.
Fields
range: (usize, usize)The byte offsets where the hashtag is located. The first index is the location of the # or $ character; the second is the location of the first character following the hashtag.
text: StringThe text of the hashtag, without the leading # or $ character.