Struct egg_mode::entities::MentionEntity[][src]

pub struct MentionEntity {
    pub id: u64,
    pub range: (usize, usize),
    pub name: String,
    pub screen_name: String,
}
Represnts a user mention extracted from another piece of text.

Fields

id: u64

Numeric ID of the mentioned user.

range: (usize, usize)

The byte offsets where the user mention is located in the original text. The first index is the location of the @ symbol; the second is the location of the first character following the user screen name.

name: String

Display name of the mentioned user.

screen_name: String

Screen name of the mentioned user, without the leading @ symbol.