Struct egg_mode::entities::UrlEntity [−][src]
pub struct UrlEntity {
pub display_url: String,
pub expanded_url: Option<String>,
pub range: (usize, usize),
pub url: String,
}Expand description
Represents a link extracted from another piece of text.
Fields
display_url: StringA truncated URL meant to be displayed inline with the text.
expanded_url: Option<String>The URL that the t.co URL resolves to.
Meant to be used as hover-text when a user mouses over a link.
range: (usize, usize)The byte offsets in the companion text where the URL was extracted from.
url: StringThe t.co URL extracted from the companion text.