A composite error type for errors that can occur while interacting with Twitter.
Any action that crosses the network to call Twitter has many places where it can go wrong.
Whether it’s a bad network connection, a revoked authorization token, a deleted tweet, or
anything in between, those errors are all represented in the (rather sprawling) Error enum.
Any errors direct from Twitter are represented as a collection of TwitterErrorCodes,
contained in a TwitterErrors wrapper, and held in the Error::TwitterError enum variant.
For more information, see the documentation for the Error enum.
Structs
- Media
Error - Represents an error that can occur during media processing.
- Twitter
Error Code - Represents a specific error returned from a Twitter API call.
- Twitter
Errors - Represents a collection of errors returned from a Twitter API call.
Enums
- Error
- A set of errors that can occur when interacting with Twitter.
Type Aliases
- Result
- Convenient alias to a Result containing a local Error type