Struct egg_mode::error::TwitterErrorCode[][src]

pub struct TwitterErrorCode {
    pub message: String,
    pub code: i32,
}
Represents a specific error returned from a Twitter API call.

Fields

message: String

The error message returned by Twitter.

code: i32

The numeric error code returned by Twitter. A list of possible error codes can be found in the API documentation.