pub fn statuses(list: ListID, with_rts: bool, token: &Token) -> TimelineExpand description
Begin navigating the collection of tweets made by the users added to the given list.
The interface for loading statuses from a list is exactly the same as loading from a personal
timeline. see the Timeline docs for details.