pub fn subscribers(list: ListID, token: &Token) -> CursorIter<UserCursor>Expand description
Look up the users that have subscribed to the given list.
This function returns a Stream over the users returned by Twitter. This method defaults to
reeturning 20 users in a single network call; the maximum is 5000.