pub struct List {
pub name: String,
pub user: TwitterUser,
pub slug: String,
pub id: u64,
pub subscriber_count: u64,
pub member_count: u64,
pub full_name: String,
pub description: String,
pub uri: String,
pub created_at: DateTime<Utc>,
}Expand description
Represents the metadata for a list.
Because of the myriad ways to reference a list, there are a few seemingly-redundant fields on here. It’s worthwhile to understand all the referential fields:
nameis the human-readable name of the list. Notably, this can contain spaces and uppercase letters.slugis simplynameconverted to a format that can be put into a URL and used to reference the list for API calls.full_nameis how you’d link the list as a @mention, in the form@screen_name/slug.idis the numeric ID, which can be used withListID::from_idto make aListIDfor the list.uriis how you assemble a link to the list. Start with"https://twitter.com", concat this field to the end, and you have a full URL. Note that the field does start with its own slash.useris a mostly-populatedTwitterUsercorresponding to the creator of the list. If you combineuser.screen_nameoruser.idwithslug, you can send them toListID::from_slugto make aListIDfor the list.
Fields
name: StringThe name of the list.
user: TwitterUserThe user who created the list.
slug: StringThe “slug” of a list, that can be combined with its creator’s UserID to refer to the list.
id: u64The numeric ID of the list.
subscriber_count: u64The number of accounts “subscribed” to the list, for whom it will appear in their collection of available lists.
member_count: u64The number of accounts added to the list.
full_name: StringThe full name of the list, preceded by @, that can be used to link to the list as part of
a tweet, direct message, or other place on Twitter where @mentions are parsed.
description: StringThe description of the list, as entered by its creator.
uri: StringThe full name of the list, preceded by /, that can be preceded with https://twitter.com
to create a link to the list.
created_at: DateTime<Utc>UTC timestamp of when the list was created.