pub struct SearchResult {
pub url: String,
pub results: Vec<Place>,
}Expand description
Represents the result of a location search, either via reverse_geocode or search.
Fields
url: StringThe full URL used to pull the result list. This can be fed to the _url version of your
original call to avoid having to fill out the argument list again.
results: Vec<Place>The list of results from the search.