request_post_json

Function request_post_json 

pub fn request_post_json<B: Serialize>(
    uri: &str,
    token: &Token,
    body: B,
) -> Request<Body>
Assemble a signed POST request to the given URL with the given JSON body.

This method of building requests allows you to use endpoints that require a request body of plain text or JSON, like POST media/metadata/create. Note that this function does not encode its parameters into the OAuth signature, so take care if the endpoint you’re using lists parameters as part of its specification.