pub enum ResultType {
Recent,
Popular,
Mixed,
}Expand description
Represents what kind of tweets should be included in search results.
Variants
Recent
Return only the most recent tweets in the response.
Popular
Return only the most popular tweets in the response.
Mixed
Include both popular and real-time results in the response.