pub struct SearchResult {
pub statuses: Vec<Tweet>,
pub query: String,
pub max_id: u64,
pub since_id: u64,
/* private fields */
}Expand description
Represents a page of search results, along with metadata to request the next or previous page.
Fields
statuses: Vec<Tweet>The list of statuses in this page of results.
query: StringThe query used to generate this page of results. Note that changing this will not affect the
next_page method.
max_id: u64Last tweet id in this page of results. This id can be used in SearchBuilder::since_tweet
since_id: u64First tweet id in this page of results. This id can be used in SearchBuilder::since_tweet
Implementations
Sourceimpl SearchResult
impl SearchResult