terms

Function terms 

pub async fn terms(token: &Token) -> Result<Response<String>>
Returns a future that resolves to the current Twitter Terms of Service as plain text.

While the official home of Twitter’s TOS is https://twitter.com/tos, this allows you to obtain a plain-text copy of it to display in your application.