pub struct TrendLocation {
pub country: String,
pub country_code: Option<String>,
pub name: String,
pub parentid: u32,
pub place_type: PlaceType,
pub url: String,
pub woeid: u32,
}Expand description
Reprsent the locations that Twitter has trending topic information
Fields
country: StringThe country of the location that Twitter has trending topic information for.
country_code: Option<String>short alphabetic or numeric geographical codes developed to represent countries and dependent areas.
name: StringThe location with trending topic information.
parentid: u32The woeid of the parent place.
place_type: PlaceTypeThe code and related name to specify the kind of location.
url: StringThe related url of woeid of the location. Note that the url returned in the response, is no longer valid.
woeid: u32The “where on earth identifier”