[][src]Struct egg_mode::tweet::TimelineFuture

#[must_use = "futures do nothing unless polled"]pub struct TimelineFuture { /* fields omitted */ }

Future which represents loading from a Timeline.

When this future completes, it will either return the tweets given by Twitter (after having updated the IDs in the parent Timeline) or the error encountered when loading or parsing the response.