Struct egg_mode::tweet::TweetSource[][src]

pub struct TweetSource {
    pub name: String,
    pub url: String,
}
Represents the app from which a specific tweet was posted.

This struct is parsed out of the HTML anchor tag that Twitter returns as part of each tweet. This way you can format the source link however you like without having to parse the values out yourself.

Note that if you’re going to reconstruct a link from this, the source URL has rel="nofollow" in the anchor tag.

Fields

name: String

The name of the app, given by its developer.

url: String

The URL for the app, given by its developer.