pub struct RelationLookup {
pub name: String,
pub screen_name: String,
pub id: u64,
pub connections: Vec<Connection>,
}Expand description
Represents the relation the authenticated user has to a given account.
This is returned by relation_lookup, as opposed to Relationship, which is returned by
relation.
Fields
name: StringThe display name of the target account.
screen_name: StringThe screen name of the target account.
id: u64The numeric ID of the target account.
connections: Vec<Connection>The ways the target account is connected to the authenticated user.
If the target account has no relation to the authenticated user, this will not be empty; its
only element will be None.