Struct egg_mode::user::UserEntities[][src]

pub struct UserEntities {
    pub description: UserEntityDetail,
    pub url: Option<UserEntityDetail>,
}
Container for URL entity information that may be paired with a user’s profile.

Fields

description: UserEntityDetail

URL information that has been parsed out of the user’s description. If no URLs were detected, then the contained Vec will be empty.

url: Option<UserEntityDetail>

Link information for the user’s url.

If url is present on the user’s profile, so will this field. Twitter validates the URL entered to a user’s profile when they save it, so this can be reasonably assumed to have URL information if it’s present.