Struct egg_mode::user::UserEntityDetail[][src]

pub struct UserEntityDetail {
    pub urls: Vec<UrlEntity>,
}
Represents a collection of URL entity information paired with a specific user profile field.

Fields

urls: Vec<UrlEntity>

Collection of URL entity information.

There should be one of these per URL in the paired field. In the case of the user’s description, if no URLs are present, this field will still be present, but empty.