[−][src]Struct egg_mode::direct::DirectMessage
the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Represents a single direct message.
As a DM has far less metadata than a regular tweet, the structure consequently contains far
fewer fields. The basic fields are id, text, entities, and created_at; everything else
either refers to the sender or receiver in some manner.
Fields
id: u64the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Numeric ID for this DM.
created_at: DateTime<Utc>the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
UTC timestamp from when this DM was created.
text: Stringthe direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
The text of the DM.
entities: DMEntitiesthe direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Link, hashtag, and user mention information parsed out of the DM.
sender_screen_name: Stringthe direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
The screen name of the user who sent the DM.
sender_id: u64the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
The ID of the user who sent the DM.
sender: Box<TwitterUser>the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Full information of the user who sent the DM.
recipient_screen_name: Stringthe direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
The screen name of the user who received the DM.
recipient_id: u64the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
The ID of the user who received the DM.
recipient: Box<TwitterUser>the direct message endpoints used in this module are no longer in service, and this module has not been migrated over to the DM Events API
Full information for the user who received the DM.