Struct egg_mode::error::TwitterErrorCode [−][src]
Represents a specific error returned from a Twitter API call.
Fields
message: StringThe error message returned by Twitter.
code: i32The numeric error code returned by Twitter. A list of possible error codes can be found in the API documentation.