pub struct SearchBuilder { /* private fields */ }Expand description
Represents a location search query before it is sent.
The available methods on this builder struct allow you to specify optional parameters to the search operation. Where applicable, each method lists its default value and acceptable ranges.
To complete your search setup and send the query to Twitter, hand your tokens to call. The
list of results from Twitter will be returned, as well as a URL to perform the same search via
search_url.
Implementations
Sourceimpl SearchBuilder
impl SearchBuilder
Sourcepub fn accuracy(self, accuracy: Accuracy) -> Self
pub fn accuracy(self, accuracy: Accuracy) -> Self
Expands the area to search to the given radius. By default, this is zero.
From Twitter: “If coming from a device, in practice, this value is whatever accuracy the device has measuring its location (whether it be coming from a GPS, WiFi triangulation, etc.).”
Sourcepub fn granularity(self, granularity: PlaceType) -> Self
pub fn granularity(self, granularity: PlaceType) -> Self
Sets the minimal specificity of what kind of results to return. For example, passing City
to this will make the eventual result exclude neighborhoods and points.
Sourcepub fn max_results(self, max_results: u32) -> Self
pub fn max_results(self, max_results: u32) -> Self
Restricts the maximum number of results returned in this search. This is not a guarantee that the search will return this many results, but instead provides a hint as to how many “nearby” results to return.
From experimentation, this value has a default of 20 and a maximum of 100. If fewer locations match the search parameters, fewer places will be returned.
From Twitter: “Ideally, only pass in the number of places you intend to display to the user here.”
Sourcepub fn contained_within(self, contained_id: String) -> Self
pub fn contained_within(self, contained_id: String) -> Self
Restricts results to those contained within the given Place ID.
Sourcepub fn attribute(self, attribute_key: String, attribute_value: String) -> Self
pub fn attribute(self, attribute_key: String, attribute_value: String) -> Self
Restricts results to those with the given attribute. A list of common attributes are
available in Twitter’s documentation for Places. Custom attributes are supported in
this search, if you know them. This function may be called multiple times with different
attribute_key values to combine attribute search parameters.
For example, .attribute("street_address", "123 Main St") searches for places with the
given street address.