pub fn request_delete(
uri: &str,
token: &Token,
params: Option<&ParamList>,
) -> Request<Body>Expand description
Assemble a signed DELETE request to the given URL with the given parameters.
The given parameters, if present, will be appended to the given uri as a percent-encoded
query string. If the given token is not a Bearer token, the parameters will also be used to
create the OAuth signature.