Function egg_mode::raw::response_raw_bytes[][src]

pub async fn response_raw_bytes(
    request: Request<Body>
) -> Result<(Headers, Vec<u8>)>
Loads the given request, parses the headers and response for potential errors given by Twitter, and returns the headers and raw bytes returned from the response.