pub struct RateLimitStatus {
pub direct: HashMap<DirectMethod, Response<()>>,
pub place: HashMap<PlaceMethod, Response<()>>,
pub search: HashMap<SearchMethod, Response<()>>,
pub service: HashMap<ServiceMethod, Response<()>>,
pub tweet: HashMap<TweetMethod, Response<()>>,
pub user: HashMap<UserMethod, Response<()>>,
pub list: HashMap<ListMethod, Response<()>>,
}Expand description
Represents the current rate-limit status of many Twitter API calls.
This is organized by module, so for example, if you wanted to see your rate-limit status for
tweet::home_timeline, you could access it like this:
use egg_mode::service::TweetMethod;
println!("home_timeline calls remaining: {}",
status.tweet[&TweetMethod::HomeTimeline].rate_limit_status.remaining);It’s important to note that not every API method is available through this call. Namely, most
calls that require a POST under-the-hood (those that add or modify data with the Twitter
service) are not shown through this method. For a listing of methods available for rate-limit
querying, see the *Method enums available in egg_mode::service.
Fields
direct: HashMap<DirectMethod, Response<()>>The rate-limit status for methods in the direct module.
place: HashMap<PlaceMethod, Response<()>>The rate-limit status for methods in the place module.
search: HashMap<SearchMethod, Response<()>>The rate-limit status for methods in the search module.
service: HashMap<ServiceMethod, Response<()>>The rate-limit status for methods in the service module.
tweet: HashMap<TweetMethod, Response<()>>The rate-limit status for methods in the tweet module.
user: HashMap<UserMethod, Response<()>>The rate-limit status for methods in the user module.
list: HashMap<ListMethod, Response<()>>The rate-limit status for methods in the list module.